@@ -1,7 +1,7 @@
 package App::wdq;
 use v5.14;
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.2.2';
 
 1;
 __END__
@@ -52,16 +52,16 @@ Get a documented list of all command line options:
 =head1 EXAMPLES
 
   # get all parts of the solar system
-  wdq -q '{ ?c wdt:P361 wd:Q544 }'
+  wdq -q '?c wdt:P361 wd:Q544'
 
   # get all references used at an item
-  wdq -q '{ wd:Q1 ?prop [ prov:wasDerivedFrom ?ref ] }'
+  wdq -q 'wd:Q1 ?prop [ prov:wasDerivedFrom ?ref ]'
 
   # print expanded SPARQL query 
-  wdq -n -q '{ ?c wdt:P361 wd:Q544 }'
+  wdq -n -q '?c wdt:P361 wd:Q544'
   
-  # execute query and return tab-separated values
-  wdq -f tsv < query
+  # execute query and return first 10 tab-separated values
+  wdq -f tsv --limit 10 < query
 
   # execute query, abbreviate Wikidata identifier, emit simple JSON
   wdq -f simple --ids < query
